hammant 2003/01/05 15:24:46
Modified: altrmi/src/java/org/apache/excalibur/altrmi/common
MethodFacadeReply.java MethodFacadeRequest.java
MethodReply.java MethodRequest.java
NoSuchReferenceException.java
NoSuchReferenceReply.java
NoSuchSessionException.java
NotPublishedException.java NotPublishedReply.java
OpenConnectionReply.java OpenConnectionRequest.java
PingReply.java PingRequest.java
PublishedNameRequest.java RawRequest.java
RequestFailedReply.java
RmiAltrmiInvocationHandler.java SameVMReply.java
SuspendedReply.java TryLaterReply.java
UserPasswordAuthentication.java
altrmi/src/java/org/apache/excalibur/altrmi/generator
BCELProxyGeneratorImpl.java ProxyGeneratorImpl.java
altrmi/src/java/org/apache/excalibur/altrmi/remotable
RemotableExtensionManager.java
altrmi/src/java/org/apache/excalibur/altrmi/server
AltrmiServer.java MethodInvocationHandler.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl
AbstractServer.java DefaultAuthenticator.java
DefaultMethodInvocationHandler.java
ServerCustomStreamReadWriter.java
ServerObjectStreamReadWriter.java
ServerStreamReadWriter.java
StreamServerConnection.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters
InvocationHandlerAdapter.java
MarshalledInvocationHandlerAdapter.java
PublicationAdapter.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback
CallbackServerClassAltrmiFactory.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket
CallbackEnabledSocketCustomStreamReadWriter.java
CallbackEnabledSocketCustomStreamServer.java
CallbackServerClientReadWriter.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/classretrievers
AbstractDynamicGeneratorClassRetriever.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/direct
DirectMarshalledServer.java DirectServer.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/http
CustomHttpServer.java CustomHttpServlet.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/piped
AbstractPipedServer.java
altrmi/src/java/org/apache/excalibur/altrmi/server/impl/rmi
RmiInovcationAdapter.java RmiServer.java
Log:
More renames. AltrMI purged as prefix in 90% of cases.
Revision Changes Path
1.6 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodFacadeReply.java
Index: MethodFacadeReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodFacadeReply.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- MethodFacadeReply.java 23 May 2002 21:37:19 -0000 1.5
+++ MethodFacadeReply.java 5 Jan 2003 23:24:43 -0000 1.6
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class MethodFacadeReply extends AltrmiReply
+public final class MethodFacadeReply extends Reply
{
static final long serialVersionUID = 3332468131008501932L;
@@ -77,12 +77,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.METHODFACADEREPLY;
+ return ReplyConstants.METHODFACADEREPLY;
}
/**
1.5 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodFacadeRequest.java
Index: MethodFacadeRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodFacadeRequest.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- MethodFacadeRequest.java 23 May 2002 21:37:19 -0000 1.4
+++ MethodFacadeRequest.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -61,12 +61,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiRequestConstants
+ * @see RequestConstants
*
*/
public int getRequestCode()
{
- return AltrmiRequestConstants.METHODFACADEREQUEST;
+ return RequestConstants.METHODFACADEREQUEST;
}
/**
1.5 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodReply.java
Index: MethodReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- MethodReply.java 23 May 2002 21:37:19 -0000 1.4
+++ MethodReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class MethodReply extends AltrmiReply
+public final class MethodReply extends Reply
{
static final long serialVersionUID = -4177121668966829330L;
@@ -62,12 +62,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.METHODREPLY;
+ return ReplyConstants.METHODREPLY;
}
/**
1.5 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodRequest.java
Index: MethodRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/MethodRequest.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- MethodRequest.java 23 May 2002 21:37:19 -0000 1.4
+++ MethodRequest.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -101,12 +101,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiRequestConstants
+ * @see RequestConstants
*
*/
public int getRequestCode()
{
- return AltrmiRequestConstants.METHODREQUEST;
+ return RequestConstants.METHODREQUEST;
}
/**
1.5 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchReferenceException.java
Index: NoSuchReferenceException.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchReferenceException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- NoSuchReferenceException.java 23 May 2002 21:37:19 -0000 1.4
+++ NoSuchReferenceException.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -14,7 +14,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class NoSuchReferenceException extends AltrmiInvocationException
+public class NoSuchReferenceException extends InvocationException
{
static final long serialVersionUID = -2716140641916481754L;
1.5 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchReferenceReply.java
Index: NoSuchReferenceReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchReferenceReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- NoSuchReferenceReply.java 23 May 2002 21:37:19 -0000 1.4
+++ NoSuchReferenceReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -49,12 +49,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.NOSUCHREFERENCEREPLY;
+ return ReplyConstants.NOSUCHREFERENCEREPLY;
}
/**
1.2 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchSessionException.java
Index: NoSuchSessionException.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NoSuchSessionException.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- NoSuchSessionException.java 5 Jan 2003 22:05:02 -0000 1.1
+++ NoSuchSessionException.java 5 Jan 2003 23:24:43 -0000 1.2
@@ -14,7 +14,7 @@
* @author Paul Hammant
* @version $Revision$
*/
-public class NoSuchSessionException extends AltrmiInvocationException
+public class NoSuchSessionException extends InvocationException
{
static final long serialVersionUID = -111L;
1.5 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NotPublishedException.java
Index: NotPublishedException.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NotPublishedException.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- NotPublishedException.java 23 May 2002 21:37:19 -0000 1.4
+++ NotPublishedException.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -14,7 +14,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class NotPublishedException extends AltrmiInvocationException
+public class NotPublishedException extends InvocationException
{
static final long serialVersionUID = 2764580329860037436L;
1.5 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NotPublishedReply.java
Index: NotPublishedReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/NotPublishedReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- NotPublishedReply.java 23 May 2002 21:37:19 -0000 1.4
+++ NotPublishedReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -14,7 +14,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class NotPublishedReply extends AltrmiReply
+public class NotPublishedReply extends Reply
{
static final long serialVersionUID = 4732484997343410452L;
@@ -31,11 +31,11 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.NOTPUBLISHEDREPLY;
+ return ReplyConstants.NOTPUBLISHEDREPLY;
}
}
1.5 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/OpenConnectionReply.java
Index: OpenConnectionReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/OpenConnectionReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- OpenConnectionReply.java 23 May 2002 21:37:19 -0000 1.4
+++ OpenConnectionReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class OpenConnectionReply extends AltrmiReply implements Sessionable
+public final class OpenConnectionReply extends Reply implements Sessionable
{
static final long serialVersionUID = 5709776827804565629L;
@@ -54,12 +54,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.OPENCONNECTIONREPLY;
+ return ReplyConstants.OPENCONNECTIONREPLY;
}
/**
1.6 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/OpenConnectionRequest.java
Index: OpenConnectionRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/OpenConnectionRequest.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- OpenConnectionRequest.java 13 Oct 2002 11:54:26 -0000 1.5
+++ OpenConnectionRequest.java 5 Jan 2003 23:24:43 -0000 1.6
@@ -19,7 +19,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class OpenConnectionRequest extends AltrmiRequest
+public final class OpenConnectionRequest extends Request
{
static final long serialVersionUID = 1773735791378198918L;
@@ -55,12 +55,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiRequestConstants
+ * @see RequestConstants
*
*/
public int getRequestCode()
{
- return AltrmiRequestConstants.OPENCONNECTIONREQUEST;
+ return RequestConstants.OPENCONNECTIONREQUEST;
}
/**
1.5 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PingReply.java
Index: PingReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PingReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- PingReply.java 23 May 2002 21:37:19 -0000 1.4
+++ PingReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -23,11 +23,11 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.PINGREPLY;
+ return ReplyConstants.PINGREPLY;
}
}
1.5 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PingRequest.java
Index: PingRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PingRequest.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- PingRequest.java 23 May 2002 21:37:19 -0000 1.4
+++ PingRequest.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -14,7 +14,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class PingRequest extends AltrmiRequest
+public final class PingRequest extends Request
{
static final long serialVersionUID = -3908905385947590608L;
@@ -23,11 +23,11 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiRequestConstants
+ * @see RequestConstants
*
*/
public int getRequestCode()
{
- return AltrmiRequestConstants.PINGREQUEST;
+ return RequestConstants.PINGREQUEST;
}
}
1.5 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PublishedNameRequest.java
Index: PublishedNameRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/PublishedNameRequest.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- PublishedNameRequest.java 23 May 2002 21:37:19 -0000 1.4
+++ PublishedNameRequest.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public abstract class PublishedNameRequest extends AltrmiRequest
+public abstract class PublishedNameRequest extends Request
{
static final long serialVersionUID = -1313413018904303303L;
1.3 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RawRequest.java
Index: RawRequest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RawRequest.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- RawRequest.java 26 Nov 2002 06:09:55 -0000 1.2
+++ RawRequest.java 5 Jan 2003 23:24:43 -0000 1.3
@@ -18,7 +18,7 @@
* @author Paul Hammant
* @version $Revision$
*/
-public class RawRequest extends AltrmiRequest
+public class RawRequest extends Request
{
private String m_methodSignature;
private Object[] m_args;
@@ -45,7 +45,7 @@
public int getRequestCode()
{
- return AltrmiRequestConstants.METHODASYNCREQUEST;
+ return RequestConstants.METHODASYNCREQUEST;
}
public void writeExternal( ObjectOutput out ) throws IOException
1.5 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RequestFailedReply.java
Index: RequestFailedReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RequestFailedReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- RequestFailedReply.java 23 May 2002 21:37:19 -0000 1.4
+++ RequestFailedReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class RequestFailedReply extends AltrmiReply
+public final class RequestFailedReply extends Reply
{
static final long serialVersionUID = -708020416286440120L;
@@ -62,12 +62,12 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.REQUESTFAILEDREPLY;
+ return ReplyConstants.REQUESTFAILEDREPLY;
}
/**
1.4 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RmiAltrmiInvocationHandler.java
Index: RmiAltrmiInvocationHandler.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/RmiAltrmiInvocationHandler.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- RmiAltrmiInvocationHandler.java 23 May 2002 21:37:19 -0000 1.3
+++ RmiAltrmiInvocationHandler.java 5 Jan 2003 23:24:43 -0000 1.4
@@ -31,5 +31,5 @@
* @throws RemoteException in case there is outage.
*
*/
- AltrmiReply handleInvocation( AltrmiRequest request ) throws RemoteException;
+ Reply handleInvocation( Request request ) throws RemoteException;
}
1.2 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/SameVMReply.java
Index: SameVMReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/SameVMReply.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- SameVMReply.java 13 Oct 2002 11:54:26 -0000 1.1
+++ SameVMReply.java 5 Jan 2003 23:24:43 -0000 1.2
@@ -14,7 +14,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class SameVMReply extends AltrmiReply
+public final class SameVMReply extends Reply
{
static final long serialVersionUID = -3567039115479930599L;
@@ -31,11 +31,11 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.SAMEVMREPLY;
+ return ReplyConstants.SAMEVMREPLY;
}
}
1.5 +3 -3
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/SuspendedReply.java
Index: SuspendedReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/SuspendedReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- SuspendedReply.java 23 May 2002 21:37:19 -0000 1.4
+++ SuspendedReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -23,11 +23,11 @@
* This is quicker than instanceof for type checking.
*
* @return the representative code
- * @see AltrmiReplyConstants
+ * @see ReplyConstants
*
*/
public int getReplyCode()
{
- return AltrmiReplyConstants.SUSPENDEDREPLY;
+ return ReplyConstants.SUSPENDEDREPLY;
}
}
1.5 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/TryLaterReply.java
Index: TryLaterReply.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/TryLaterReply.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- TryLaterReply.java 23 May 2002 21:37:19 -0000 1.4
+++ TryLaterReply.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public abstract class TryLaterReply extends AltrmiReply
+public abstract class TryLaterReply extends Reply
{
static final long serialVersionUID = -6459959300465362602L;
1.5 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/UserPasswordAuthentication.java
Index: UserPasswordAuthentication.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/common/UserPasswordAuthentication.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- UserPasswordAuthentication.java 23 May 2002 21:37:19 -0000 1.4
+++ UserPasswordAuthentication.java 5 Jan 2003 23:24:43 -0000 1.5
@@ -18,7 +18,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public final class UserPasswordAuthentication extends AltrmiAuthentication
+public final class UserPasswordAuthentication extends Authentication
{
static final long serialVersionUID = -5410097680279080054L;
1.10 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/generator/BCELProxyGeneratorImpl.java
Index: BCELProxyGeneratorImpl.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/generator/BCELProxyGeneratorImpl.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- BCELProxyGeneratorImpl.java 4 Jan 2003 22:17:19 -0000 1.9
+++ BCELProxyGeneratorImpl.java 5 Jan 2003 23:24:44 -0000 1.10
@@ -540,7 +540,7 @@
* {
* t.printStackTrace();
* throw new org.apache.excalibur.altrmi.common.
- AltrmiInvocationException("Should never get here:"
+t.getMessage());
+ InvocationException("Should never get here:"
+t.getMessage());
* }
* }
* ================================================
@@ -730,7 +730,7 @@
Constants.INVOKEVIRTUAL));
il.append(
m_factory.createNew(
- "org.apache.excalibur.altrmi.common.AltrmiInvocationException"));
+ "org.apache.excalibur.altrmi.common.InvocationException"));
il.append(InstructionConstants.DUP);
il.append(m_factory.createNew("java.lang.StringBuffer"));
il.append(InstructionConstants.DUP);
@@ -766,7 +766,7 @@
Constants.INVOKEVIRTUAL));
il.append(
m_factory.createInvoke(
- "org.apache.excalibur.altrmi.common.AltrmiInvocationException",
+ "org.apache.excalibur.altrmi.common.InvocationException",
"<init>",
Type.VOID,
new Type[] { Type.STRING },
1.18 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/generator/ProxyGeneratorImpl.java
Index: ProxyGeneratorImpl.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/generator/ProxyGeneratorImpl.java,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- ProxyGeneratorImpl.java 4 Jan 2003 22:17:19 -0000 1.17
+++ ProxyGeneratorImpl.java 5 Jan 2003 23:24:44 -0000 1.18
@@ -335,7 +335,7 @@
m_classSource.println( " t.printStackTrace(); " );
m_classSource.println(
" throw new org.apache.excalibur.altrmi.common."
- + "AltrmiInvocationException(\"Should never get here: \"
+t.getMessage());");
+ + "InvocationException(\"Should never get here: \" +t.getMessage());");
m_classSource.println( " }" );
m_classSource.println( " }" );
}
@@ -374,7 +374,7 @@
m_classSource.println( " t.printStackTrace(); " );
m_classSource.println(
" throw new org.apache.excalibur.altrmi.common."
- + "AltrmiInvocationException(\"Should never get here: \"
+t.getMessage());");
+ + "InvocationException(\"Should never get here: \" +t.getMessage());");
m_classSource.println( " }" );
m_classSource.println( " } finally { " );
m_classSource.println( " m_asyncInvocations.removeAllElements();");
@@ -401,7 +401,7 @@
m_classSource.println( " t.printStackTrace(); " );
m_classSource.println(
" throw new org.apache.excalibur.altrmi.common."
- + "AltrmiInvocationException(\"Should never get here: \"
+t.getMessage());");
+ + "InvocationException(\"Should never get here: \" +t.getMessage());");
m_classSource.println( " }" );
m_classSource.println( " }" );
1.2 +6 -7
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/remotable/RemotableExtensionManager.java
Index: RemotableExtensionManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/remotable/RemotableExtensionManager.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- RemotableExtensionManager.java 5 Jan 2003 23:11:41 -0000 1.1
+++ RemotableExtensionManager.java 5 Jan 2003 23:24:44 -0000 1.2
@@ -73,8 +73,7 @@
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
-import org.apache.excalibur.altrmi.common.ProxyGenerator;
-import org.apache.excalibur.altrmi.server.AltrmiProxyGenerator;
+import org.apache.excalibur.altrmi.server.ProxyGenerator;
import org.apache.excalibur.altrmi.server.PublicationDescription;
import org.apache.excalibur.altrmi.server.PublicationDescriptionItem;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
@@ -124,7 +123,7 @@
/** Class Retriever that fetchs the stubs on clients request */
private PlainClassRetriever m_classRetriever;
/** ProxyGenerator used to generate stubs dynamicalls */
- private ProxyGenerator m_proxyGenerator;
+ private org.apache.excalibur.altrmi.common.ProxyGenerator m_proxyGenerator;
/** Classpath entry needed by the proxyGenerator */
private String m_classpath;
/** Indicates whether the extension handler has been activated
@@ -338,14 +337,14 @@
Class clazz =
getClass().getClassLoader().loadClass(strProxyGenerator);
//Check if the class is after all a 'ClassRetriever'
- if (!ProxyGenerator.class.isAssignableFrom(clazz))
+ if
(!org.apache.excalibur.altrmi.common.ProxyGenerator.class.isAssignableFrom(clazz))
{
getLogger().error(
"\n**********************************************************************"
+ "\n Altrmi Proxy Generator["
+ strProxyGenerator
+ "] does NOT implement "
- + AltrmiProxyGenerator.class.getName()
+ + ProxyGenerator.class.getName()
+ " interface"
+ "\n"
+ "\n Proceeding further without AltRMI beside the
components for remoting"
@@ -353,7 +352,7 @@
return false;
}
- m_proxyGenerator = (ProxyGenerator) clazz.newInstance();
+ m_proxyGenerator = (org.apache.excalibur.altrmi.common.ProxyGenerator)
clazz.newInstance();
}
catch (Exception e)
{
@@ -432,7 +431,7 @@
m_classpath += File.pathSeparator
+ getClassLocation(
Class.forName(
-
"org.apache.excalibur.altrmi.common.AltrmiInvocationException"));
+ "org.apache.excalibur.altrmi.common.InvocationException"));
}
catch (ClassNotFoundException e)
1.5 +6 -6
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/AltrmiServer.java
Index: MethodInvocationHandler.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/MethodInvocationHandler.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- MethodInvocationHandler.java 24 Aug 2002 11:39:05 -0000 1.4
+++ MethodInvocationHandler.java 5 Jan 2003 23:24:44 -0000 1.5
@@ -7,7 +7,7 @@
*/
package org.apache.excalibur.altrmi.server;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
+import org.apache.excalibur.altrmi.common.Reply;
import org.apache.excalibur.altrmi.common.MethodRequest;
/**
@@ -29,7 +29,7 @@
* @return the reply for the request.
*
*/
- AltrmiReply handleMethodInvocation( MethodRequest request );
+ Reply handleMethodInvocation( MethodRequest request );
/**
* Add an implementation bean
1.10 +11 -11
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/AbstractServer.java
Index: AbstractServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/AbstractServer.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- AbstractServer.java 25 Nov 2002 21:17:08 -0000 1.9
+++ AbstractServer.java 5 Jan 2003 23:24:44 -0000 1.10
@@ -11,12 +11,12 @@
import org.apache.avalon.framework.logger.ConsoleLogger;
import org.apache.avalon.framework.logger.LogEnabled;
import org.apache.avalon.framework.logger.Logger;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.MethodRequest;
-import org.apache.excalibur.altrmi.server.AltrmiAuthenticator;
+import org.apache.excalibur.altrmi.server.Authenticator;
import org.apache.excalibur.altrmi.server.AltrmiServer;
-import org.apache.excalibur.altrmi.server.AltrmiServerConnection;
+import org.apache.excalibur.altrmi.server.ServerConnection;
import org.apache.excalibur.altrmi.server.ClassRetriever;
import org.apache.excalibur.altrmi.server.MethodInvocationHandler;
import org.apache.excalibur.altrmi.server.PublicationDescription;
@@ -128,7 +128,7 @@
*
*
*/
- public final void setAuthenticator( AltrmiAuthenticator altrmiAuthenticator )
+ public final void setAuthenticator( Authenticator altrmiAuthenticator )
{
m_inovcationHandlerAdapter.setAuthenticator( altrmiAuthenticator );
}
@@ -142,7 +142,7 @@
* @return An suitable reply.
*
*/
- public AltrmiReply handleInvocation( AltrmiRequest request )
+ public Reply handleInvocation( Request request )
{
return m_inovcationHandlerAdapter.handleInvocation( request );
}
@@ -170,7 +170,7 @@
* @param altrmiConnection The connection
*
*/
- protected void connectionStart( AltrmiServerConnection altrmiConnection )
+ protected void connectionStart( ServerConnection altrmiConnection )
{
m_connections.add( altrmiConnection );
}
@@ -180,7 +180,7 @@
* @param altrmiConnection The connection
*
*/
- protected void connectionCompleted( AltrmiServerConnection altrmiConnection )
+ protected void connectionCompleted( ServerConnection altrmiConnection )
{
m_connections.remove( altrmiConnection );
}
@@ -192,8 +192,8 @@
{
// Copy the connections into an array to avoid
ConcurrentModificationExceptions
// as the connections are closed.
- AltrmiServerConnection[] connections =
- (AltrmiServerConnection[])m_connections.toArray( new
AltrmiServerConnection[0] );
+ ServerConnection[] connections =
+ (ServerConnection[])m_connections.toArray( new ServerConnection[0] );
for ( int i = 0; i < connections.length; i++ )
{
connections[i].endConnection();
1.5 +5 -5
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/DefaultAuthenticator.java
Index: DefaultAuthenticator.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/DefaultAuthenticator.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- DefaultAuthenticator.java 21 Sep 2002 15:52:56 -0000 1.4
+++ DefaultAuthenticator.java 5 Jan 2003 23:24:44 -0000 1.5
@@ -7,8 +7,8 @@
*/
package org.apache.excalibur.altrmi.server.impl;
-import org.apache.excalibur.altrmi.common.AltrmiAuthentication;
-import org.apache.excalibur.altrmi.server.AltrmiAuthenticator;
+import org.apache.excalibur.altrmi.common.Authentication;
+import org.apache.excalibur.altrmi.server.Authenticator;
/**
* Check the Authority of a client to a service.
@@ -17,7 +17,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class DefaultAuthenticator implements AltrmiAuthenticator
+public class DefaultAuthenticator implements Authenticator
{
/**
@@ -30,7 +30,7 @@
*
*
*/
- public void checkAuthority( AltrmiAuthentication altrmiAuthentication, String
publishedService )
+ public void checkAuthority( Authentication altrmiAuthentication, String
publishedService )
{
}
1.12 +10 -10
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/DefaultMethodInvocationHandler.java
Index: DefaultMethodInvocationHandler.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/DefaultMethodInvocationHandler.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- DefaultMethodInvocationHandler.java 5 Jan 2003 22:05:02 -0000 1.11
+++ DefaultMethodInvocationHandler.java 5 Jan 2003 23:24:44 -0000 1.12
@@ -13,14 +13,14 @@
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.WeakHashMap;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
+import org.apache.excalibur.altrmi.common.InvocationException;
+import org.apache.excalibur.altrmi.common.Reply;
import org.apache.excalibur.altrmi.common.ExceptionReply;
import org.apache.excalibur.altrmi.common.FacadeRefHolder;
import org.apache.excalibur.altrmi.common.MethodReply;
import org.apache.excalibur.altrmi.common.MethodRequest;
import org.apache.excalibur.altrmi.common.NoSuchReferenceReply;
-import org.apache.excalibur.altrmi.server.AltrmiPublisher;
+import org.apache.excalibur.altrmi.server.Publisher;
import org.apache.excalibur.altrmi.server.MethodInvocationHandler;
import org.apache.excalibur.altrmi.server.PublicationDescription;
@@ -58,7 +58,7 @@
/**
* The altrmi publisher
*/
- private AltrmiPublisher m_altrmiPublisher;
+ private Publisher m_altrmiPublisher;
/**
* published thing
@@ -86,7 +86,7 @@
* @param publicationDescription The publication description
*
*/
- public DefaultMethodInvocationHandler( AltrmiPublisher altrmiPublisher, String
publishedThing,
+ public DefaultMethodInvocationHandler( Publisher altrmiPublisher, String
publishedThing,
HashMap methodMap,
PublicationDescription
publicationDescription )
{
@@ -182,7 +182,7 @@
* @return The reply.
*
*/
- public AltrmiReply handleMethodInvocation( MethodRequest request )
+ public Reply handleMethodInvocation( MethodRequest request )
{
String methodSignature = request.getMethodSignature();
@@ -190,7 +190,7 @@
if( !m_methodMap.containsKey( methodSignature ) )
{
return new ExceptionReply(
- new AltrmiInvocationException( "Method not present in impl" ) );
+ new InvocationException( "Method not present in impl" ) );
}
Method method = (Method) m_methodMap.get( methodSignature );
@@ -230,7 +230,7 @@
else
{
return new ExceptionReply(
- new AltrmiInvocationException(
+ new InvocationException(
"Exception was not serializable :" + t.getClass().getName()
) );
}
}
@@ -240,7 +240,7 @@
t.printStackTrace();
return new ExceptionReply(
- new AltrmiInvocationException(
+ new InvocationException(
"Some ServerSide exception problem :" + t.getMessage() ) );
}
}
1.8 +10 -10
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerCustomStreamReadWriter.java
Index: ServerObjectStreamReadWriter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerObjectStreamReadWriter.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ServerObjectStreamReadWriter.java 28 Oct 2002 21:58:56 -0000 1.6
+++ ServerObjectStreamReadWriter.java 5 Jan 2003 23:24:44 -0000 1.7
@@ -13,8 +13,8 @@
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.lang.reflect.Constructor;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
/**
* Class ServerObjectStreamReadWriter
@@ -106,7 +106,7 @@
* @throws IOException In an IO Exception
* @throws ClassNotFoundException If a class not found during deserialization.
*/
- protected synchronized AltrmiRequest writeReplyAndGetRequest( AltrmiReply
altrmiReply )
+ protected synchronized Request writeReplyAndGetRequest( Reply altrmiReply )
throws IOException, ClassNotFoundException
{
@@ -123,7 +123,7 @@
* @param altrmiReply The reply to write
* @throws IOException If and IO Exception
*/
- private void writeReply( AltrmiReply altrmiReply ) throws IOException
+ private void writeReply( Reply altrmiReply ) throws IOException
{
m_objectOutputStream.writeObject( altrmiReply );
@@ -157,8 +157,8 @@
* @throws IOException If an IO Exception
* @throws ClassNotFoundException If a class not found during deserialization.
*/
- private AltrmiRequest readRequest() throws IOException, ClassNotFoundException
+ private Request readRequest() throws IOException, ClassNotFoundException
{
- return (AltrmiRequest)m_objectInputStream.readObject();
+ return (Request)m_objectInputStream.readObject();
}
}
1.7 +7 -7
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerStreamReadWriter.java
Index: StreamServerConnection.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/StreamServerConnection.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- StreamServerConnection.java 4 Jan 2003 21:31:46 -0000 1.10
+++ StreamServerConnection.java 5 Jan 2003 23:24:44 -0000 1.11
@@ -13,12 +13,12 @@
import java.net.SocketException;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.EndConnectionReply;
-import org.apache.excalibur.altrmi.common.AltrmiConnectionException;
+import org.apache.excalibur.altrmi.common.ConnectionException;
import org.apache.excalibur.altrmi.common.BadConnectionException;
-import org.apache.excalibur.altrmi.server.AltrmiServerConnection;
+import org.apache.excalibur.altrmi.server.ServerConnection;
/**
* Class StreamServerConnection
@@ -28,7 +28,7 @@
* @version $Revision$
*/
public abstract class StreamServerConnection extends AbstractLogEnabled
- implements Runnable, AltrmiServerConnection
+ implements Runnable, ServerConnection
{
/**
@@ -76,8 +76,8 @@
m_readWriter.initialize();
boolean more = true;
- AltrmiRequest request = null;
- AltrmiReply reply = null;
+ Request request = null;
+ Reply reply = null;
while (more)
{
@@ -105,10 +105,10 @@
getLogger().error("Bad connection in StreamServerConnection
#0", bce);
m_readWriter.close();
}
- catch (AltrmiConnectionException ace)
+ catch (ConnectionException ace)
{
more = false;
- getLogger().error("Unexpected AltrmiConnectionException "
+ getLogger().error("Unexpected ConnectionException "
+ "in StreamServerConnection #0", ace);
m_readWriter.close();
}
1.17 +42 -42
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/InvocationHandlerAdapter.java
Index: InvocationHandlerAdapter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/InvocationHandlerAdapter.java,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -r1.16 -r1.17
--- InvocationHandlerAdapter.java 5 Jan 2003 22:05:02 -0000 1.16
+++ InvocationHandlerAdapter.java 5 Jan 2003 23:24:45 -0000 1.17
@@ -12,13 +12,13 @@
import java.util.Iterator;
import java.util.Vector;
-import org.apache.excalibur.altrmi.common.AltrmiAuthenticationException;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationException;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationHandler;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiReplyConstants;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
-import org.apache.excalibur.altrmi.common.AltrmiRequestConstants;
+import org.apache.excalibur.altrmi.common.AuthenticationException;
+import org.apache.excalibur.altrmi.common.InvocationException;
+import org.apache.excalibur.altrmi.common.InvocationHandler;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.ReplyConstants;
+import org.apache.excalibur.altrmi.common.Request;
+import org.apache.excalibur.altrmi.common.RequestConstants;
import org.apache.excalibur.altrmi.common.ClassReply;
import org.apache.excalibur.altrmi.common.ClassRequest;
import org.apache.excalibur.altrmi.common.ClassRetrievalFailedReply;
@@ -46,7 +46,7 @@
import org.apache.excalibur.altrmi.common.MethodAsyncRequest;
import org.apache.excalibur.altrmi.common.RawRequest;
import org.apache.excalibur.altrmi.common.NoSuchSessionException;
-import org.apache.excalibur.altrmi.server.AltrmiAuthenticator;
+import org.apache.excalibur.altrmi.server.Authenticator;
import org.apache.excalibur.altrmi.server.ClassRetrievalException;
import org.apache.excalibur.altrmi.server.ClassRetriever;
import org.apache.excalibur.altrmi.server.MethodInvocationHandler;
@@ -63,7 +63,7 @@
* @version $Revision$
*/
public class InvocationHandlerAdapter extends PublicationAdapter
- implements AltrmiInvocationHandler
+ implements InvocationHandler
{
private static long c_session = 0;
@@ -72,7 +72,7 @@
private HashMap m_sessions = new HashMap();
private boolean m_suspend = false;
private ClassRetriever m_classRetriever = new NoClassRetriever();
- private AltrmiAuthenticator m_altrmiAuthenticator = new DefaultAuthenticator();
+ private Authenticator m_altrmiAuthenticator = new DefaultAuthenticator();
/**
* Set a ClassRetriever
@@ -93,7 +93,7 @@
* @param altrmiAuthenticator The authenticator
*
*/
- public final void setAuthenticator( AltrmiAuthenticator altrmiAuthenticator )
+ public final void setAuthenticator( Authenticator altrmiAuthenticator )
{
m_altrmiAuthenticator = altrmiAuthenticator;
}
@@ -107,7 +107,7 @@
* @return The reply.
*
*/
- public AltrmiReply handleInvocation( AltrmiRequest request )
+ public Reply handleInvocation( Request request )
{
if( m_suspend == true )
@@ -117,54 +117,54 @@
// Method request is positioned first as
// it is the one we want to be most speedy.
- if( request.getRequestCode() == AltrmiRequestConstants.METHODREQUEST )
+ if( request.getRequestCode() == RequestConstants.METHODREQUEST )
{
return doMethodRequest( request );
}
- else if( request.getRequestCode() ==
AltrmiRequestConstants.METHODFACADEREQUEST )
+ else if( request.getRequestCode() == RequestConstants.METHODFACADEREQUEST )
{
return doMethodFacadeRequest( request );
}
- else if( request.getRequestCode() ==
AltrmiRequestConstants.METHODASYNCREQUEST )
+ else if( request.getRequestCode() == RequestConstants.METHODASYNCREQUEST )
{
return doMethodAsyncRequest( (MethodAsyncRequest) request );
}
- else if( request.getRequestCode() == AltrmiRequestConstants.GCREQUEST )
+ else if( request.getRequestCode() == RequestConstants.GCREQUEST )
{
return doGarbageCollectionRequest( request );
}
- else if( request.getRequestCode() == AltrmiRequestConstants.LOOKUPREQUEST )
+ else if( request.getRequestCode() == RequestConstants.LOOKUPREQUEST )
{
return doLookupRequest( request );
}
- else if( request.getRequestCode() == AltrmiRequestConstants.CLASSREQUEST )
+ else if( request.getRequestCode() == RequestConstants.CLASSREQUEST )
{
return doClassRequest( request );
}
- else if( request.getRequestCode() ==
AltrmiRequestConstants.OPENCONNECTIONREQUEST )
+ else if( request.getRequestCode() == RequestConstants.OPENCONNECTIONREQUEST
)
{
OpenConnectionRequest openConnectionRequest = (OpenConnectionRequest)
request;
return doOpenConnectionRequest(openConnectionRequest.getMachineID());
}
- else if( request.getRequestCode() == AltrmiRequestConstants.PINGREQUEST )
+ else if( request.getRequestCode() == RequestConstants.PINGREQUEST )
{
// we could communicate back useful state info in this transaction.
return new PingReply();
}
- else if( request.getRequestCode() == AltrmiRequestConstants.LISTREQUEST )
+ else if( request.getRequestCode() == RequestConstants.LISTREQUEST )
{
return doListRequest();
}
- else if(request.getRequestCode()==
AltrmiRequestConstants.LISTMETHODSREQUEST)
+ else if(request.getRequestCode()== RequestConstants.LISTMETHODSREQUEST)
{
return doListMethodsRequest(request);
}
@@ -179,7 +179,7 @@
* @param request the request
* @return The reply
*/
- private AltrmiReply doMethodFacadeRequest( AltrmiRequest request )
+ private Reply doMethodFacadeRequest( Request request )
{
MethodFacadeRequest facadeRequest = (MethodFacadeRequest)request;
@@ -199,22 +199,22 @@
//if( !sessionExists( facadeRequest.getSession() ) )
//{
// return new ExceptionReply(
- // new AltrmiInvocationException( "TODO - you dirty rat/hacker" ) );
+ // new InvocationException( "TODO - you dirty rat/hacker" ) );
//}
MethodInvocationHandler methodInvocationHandler =
getMethodInvocationHandler( publishedThing );
- AltrmiReply ar = methodInvocationHandler.handleMethodInvocation(
facadeRequest );
+ Reply ar = methodInvocationHandler.handleMethodInvocation( facadeRequest );
- if( ar.getReplyCode() == AltrmiReplyConstants.EXCEPTIONREPLY )
+ if( ar.getReplyCode() == ReplyConstants.EXCEPTIONREPLY )
{
return ar;
}
- else if( ar.getReplyCode() >= AltrmiReplyConstants.PROBLEMREPLY )
+ else if( ar.getReplyCode() >= ReplyConstants.PROBLEMREPLY )
{
return ar;
}
- else if( ar.getReplyCode() == AltrmiReplyConstants.METHODREPLY )
+ else if( ar.getReplyCode() == ReplyConstants.METHODREPLY )
{
Object methodReply = ( (MethodReply)ar ).getReplyObject();
@@ -245,7 +245,7 @@
* @param methodFacadeRequest The request
* @return The reply
*/
- private AltrmiReply doMethodFacadeRequestArray(
+ private Reply doMethodFacadeRequestArray(
Object methodReply, MethodFacadeRequest methodFacadeRequest )
{
Object[] beanImpls = (Object[])methodReply;
@@ -301,7 +301,7 @@
* @param methodFacadeRequest The request
* @return The reply
*/
- private AltrmiReply doMethodFacadeRequestNonArray(
+ private Reply doMethodFacadeRequestNonArray(
Object beanImpl, MethodFacadeRequest methodFacadeRequest )
{
@@ -327,7 +327,7 @@
//if( !sessionExists( methodFacadeRequest.getSession() ) )
//{
// return new ExceptionReply(
- // new AltrmiInvocationException( "TODO - you dirty rat/hacker" ) );
+ // new InvocationException( "TODO - you dirty rat/hacker" ) );
//}
//TODO a decent ref number for main?
@@ -347,7 +347,7 @@
* @param request The request
* @return The reply
*/
- private AltrmiReply doMethodRequest( AltrmiRequest request )
+ private Reply doMethodRequest( Request request )
{
MethodRequest methodRequest = (MethodRequest) request;
@@ -369,7 +369,7 @@
return methodInvocationHandler.handleMethodInvocation( methodRequest );
}
- private AltrmiReply doMethodAsyncRequest(MethodAsyncRequest methodRequest)
+ private Reply doMethodAsyncRequest(MethodAsyncRequest methodRequest)
{
if (!sessionExists(methodRequest.getSession()))
@@ -413,7 +413,7 @@
* @param request The request
* @return The reply
*/
- private AltrmiReply doLookupRequest( AltrmiRequest request )
+ private Reply doLookupRequest( Request request )
{
LookupRequest lr = (LookupRequest)request;
@@ -422,7 +422,7 @@
m_altrmiAuthenticator.checkAuthority( lr.getAltrmiAuthentication(),
lr.getPublishedServiceName() );
}
- catch( AltrmiAuthenticationException aae )
+ catch( AuthenticationException aae )
{
return new ExceptionReply( aae );
}
@@ -436,7 +436,7 @@
* @param request The request
* @return The reply
*/
- private AltrmiReply doClassRequest( AltrmiRequest request )
+ private Reply doClassRequest( Request request )
{
ClassRequest cr = (ClassRequest)request;
String publishedThing = cr.getPublishedServiceName() + "_" +
cr.getObjectName();
@@ -458,7 +458,7 @@
* Do an OpenConnection request
* @return The reply.
*/
- private AltrmiReply doOpenConnectionRequest(UID machineID)
+ private Reply doOpenConnectionRequest(UID machineID)
{
if (machineID != null && machineID.equals(U_ID))
{
@@ -476,7 +476,7 @@
* Do a ListRequest
* @return The reply
*/
- private AltrmiReply doListRequest()
+ private Reply doListRequest()
{
//return the list of published objects to the server
Iterator iterator = getIteratorOfPublishedObjects();
@@ -505,7 +505,7 @@
* @param request The request
* @return The reply
*/
- private AltrmiReply doGarbageCollectionRequest( AltrmiRequest request )
+ private Reply doGarbageCollectionRequest( Request request )
{
GarbageCollectionRequest gcr = (GarbageCollectionRequest)request;
String publishedThing = gcr.getPublishedServiceName() + "_" +
gcr.getObjectName();
@@ -519,7 +519,7 @@
if( !sessionExists( session ) )
{
return new ExceptionReply(
- new AltrmiInvocationException( "TODO - you dirty rat/hacker" ) );
+ new InvocationException( "TODO - you dirty rat/hacker" ) );
}
AltrmiSession sess = (AltrmiSession) m_sessions.get( session );
@@ -550,7 +550,7 @@
* @param request The request
* @return The reply
*/
- private AltrmiReply doListMethodsRequest( AltrmiRequest request )
+ private Reply doListMethodsRequest( Request request )
{
ListMethodsRequest lReq = (ListMethodsRequest)request;
String publishedThing = lReq.getPublishedName() + "_Main";
1.5 +12 -12
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/MarshalledInvocationHandlerAdapter.java
Index: MarshalledInvocationHandlerAdapter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/MarshalledInvocationHandlerAdapter.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- MarshalledInvocationHandlerAdapter.java 26 Nov 2002 06:09:55 -0000 1.4
+++ MarshalledInvocationHandlerAdapter.java 5 Jan 2003 23:24:45 -0000 1.5
@@ -8,10 +8,10 @@
package org.apache.excalibur.altrmi.server.impl.adapters;
import java.io.IOException;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationHandler;
-import org.apache.excalibur.altrmi.common.AltrmiMarshalledInvocationHandler;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.InvocationHandler;
+import org.apache.excalibur.altrmi.common.MarshalledInvocationHandler;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.SerializationHelper;
import javax.swing.*;
@@ -23,13 +23,13 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class MarshalledInvocationHandlerAdapter implements
AltrmiMarshalledInvocationHandler
+public class MarshalledInvocationHandlerAdapter implements
MarshalledInvocationHandler
{
/**
* The invocation hamdeler
*/
- private AltrmiInvocationHandler m_altrmiInvocationHandler;
+ private InvocationHandler m_altrmiInvocationHandler;
/**
* The class loader.
*/
@@ -42,7 +42,7 @@
* @param altrmiInvocationHandler The invocation handler
*
*/
- public MarshalledInvocationHandlerAdapter( AltrmiInvocationHandler
altrmiInvocationHandler )
+ public MarshalledInvocationHandlerAdapter( InvocationHandler
altrmiInvocationHandler )
{
m_altrmiInvocationHandler = altrmiInvocationHandler;
m_classLoader = getClass().getClassLoader();
@@ -56,7 +56,7 @@
* @param classLoader The classloader
*
*/
- public MarshalledInvocationHandlerAdapter( AltrmiInvocationHandler
altrmiInvocationHandler,
+ public MarshalledInvocationHandlerAdapter( InvocationHandler
altrmiInvocationHandler,
ClassLoader classLoader )
{
m_altrmiInvocationHandler = altrmiInvocationHandler;
@@ -77,10 +77,10 @@
try
{
- AltrmiRequest ar =
- (AltrmiRequest) SerializationHelper.getInstanceFromBytes(
+ Request ar =
+ (Request) SerializationHelper.getInstanceFromBytes(
request, m_classLoader );
- AltrmiReply reply = m_altrmiInvocationHandler.handleInvocation( ar );
+ Reply reply = m_altrmiInvocationHandler.handleInvocation( ar );
return SerializationHelper.getBytesFromInstance( reply );
}
1.9 +2 -2
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/PublicationAdapter.java
Index: PublicationAdapter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/adapters/PublicationAdapter.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- PublicationAdapter.java 5 Jan 2003 22:05:02 -0000 1.8
+++ PublicationAdapter.java 5 Jan 2003 23:24:45 -0000 1.9
@@ -23,7 +23,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version $Revision$
*/
-public class PublicationAdapter implements AltrmiPublisher
+public class PublicationAdapter implements Publisher
{
/**
1.8 +13 -13
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/CallbackServerClassAltrmiFactory.java
Index: CallbackEnabledSocketCustomStreamReadWriter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackEnabledSocketCustomStreamReadWriter.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- CallbackEnabledSocketCustomStreamReadWriter.java 5 Jan 2003 23:11:29 -0000
1.7
+++ CallbackEnabledSocketCustomStreamReadWriter.java 5 Jan 2003 23:24:45 -0000
1.8
@@ -12,8 +12,8 @@
import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.excalibur.altrmi.client.ConnectionClosedException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.ExposedObjectProxy;
import org.apache.excalibur.altrmi.common.MethodRequest;
import org.apache.excalibur.altrmi.common.SerializationHelper;
@@ -44,8 +44,8 @@
private boolean m_isStopped = false;
private Object m_requestLock = new Object();
private Object m_replyLock = new Object();
- private AltrmiRequest m_request = null;
- private AltrmiReply m_reply = null;
+ private Request m_request = null;
+ private Reply m_reply = null;
private CallbackServerClientReadWriter m_callbackServerClientReadWriter;
private CallbackStreamInvocationHandler m_callbackStreamInvocationHandler;
private CallbackHostContext m_callbackHostContext;
@@ -101,18 +101,18 @@
//interpret it as a request or reply & notify the corresponding
listeners
// SHLD we need a queue here to hold the arriving packets
// TODO:WORKAROUND: Dont receive until the data is handled some way
- if( obj instanceof AltrmiRequest )
+ if( obj instanceof Request )
{
- m_request = (AltrmiRequest)obj;
+ m_request = (Request)obj;
synchronized( m_requestLock )
{
m_requestLock.notify();
}
}
- else if( obj instanceof AltrmiReply )
+ else if( obj instanceof Reply )
{
- m_reply = (AltrmiReply)obj;
+ m_reply = (Reply)obj;
synchronized( m_replyLock )
{
@@ -162,9 +162,9 @@
/**
* Method getRequestFromMessageLoop.
- * @return AltrmiRequest
+ * @return Request
*/
- private AltrmiRequest getRequestFromMessageLoop()
+ private Request getRequestFromMessageLoop()
{
//if(_replyQueue.size()==0)
@@ -188,9 +188,9 @@
/**
* Method getReplyFromMessageLoop.
- * @return AltrmiReply
+ * @return Reply
*/
- private AltrmiReply getReplyFromMessageLoop()
+ private Reply getReplyFromMessageLoop()
{
//if(_replyQueue.size()==0)
@@ -213,9 +213,9 @@
}
/*
- * @see ServerStreamReadWriter#writeReplyAndGetRequest(AltrmiReply)
+ * @see ServerStreamReadWriter#writeReplyAndGetRequest(Reply)
*/
- protected AltrmiRequest writeReplyAndGetRequest( AltrmiReply altrmiReply )
+ protected Request writeReplyAndGetRequest( Reply altrmiReply )
throws IOException, ClassNotFoundException
{
@@ -224,7 +224,7 @@
writeReply( altrmiReply );
}
- AltrmiRequest req = readRequest();
+ Request req = readRequest();
m_request = null;
@@ -236,7 +236,7 @@
* @param altrmiReply
* @throws IOException
*/
- private void writeReply( AltrmiReply altrmiReply ) throws IOException
+ private void writeReply( Reply altrmiReply ) throws IOException
{
byte[] aBytes = SerializationHelper.getBytesFromInstance( altrmiReply );
@@ -248,14 +248,14 @@
/**
* Method readRequest.
- * @return AltrmiRequest
+ * @return Request
* @throws IOException
* @throws ClassNotFoundException
*/
- private AltrmiRequest readRequest() throws IOException, ClassNotFoundException
+ private Request readRequest() throws IOException, ClassNotFoundException
{
- AltrmiRequest altrmiRequest = getRequestFromMessageLoop();
+ Request altrmiRequest = getRequestFromMessageLoop();
if( altrmiRequest instanceof MethodRequest )
{
@@ -270,11 +270,11 @@
/**
* Method postRequest.
* @param altrmiRequest
- * @return AltrmiReply
+ * @return Reply
* @throws IOException
* @throws ClassNotFoundException
*/
- protected AltrmiReply postRequest( AltrmiRequest altrmiRequest )
+ protected Reply postRequest( Request altrmiRequest )
throws IOException, ClassNotFoundException
{
@@ -285,7 +285,7 @@
writeRequest( altrmiRequest );
- AltrmiReply r = readReply();
+ Reply r = readReply();
if( r == null )
{
@@ -302,7 +302,7 @@
* @param altrmiRequest
* @throws IOException
*/
- private void writeRequest( AltrmiRequest altrmiRequest ) throws IOException
+ private void writeRequest( Request altrmiRequest ) throws IOException
{
byte[] aBytes = SerializationHelper.getBytesFromInstance( altrmiRequest );
@@ -314,11 +314,11 @@
/**
* Method readReply.
- * @return AltrmiReply
+ * @return Reply
* @throws IOException
* @throws ClassNotFoundException
*/
- private AltrmiReply readReply() throws IOException, ClassNotFoundException
+ private Reply readReply() throws IOException, ClassNotFoundException
{
return getReplyFromMessageLoop();
}
1.4 +6 -6
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackEnabledSocketCustomStreamServer.java
Index: CallbackEnabledSocketCustomStreamServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackEnabledSocketCustomStreamServer.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- CallbackEnabledSocketCustomStreamServer.java 24 Apr 2002 12:43:01 -0000
1.3
+++ CallbackEnabledSocketCustomStreamServer.java 5 Jan 2003 23:24:45 -0000
1.4
@@ -7,7 +7,7 @@
*/
package org.apache.excalibur.altrmi.server.impl.callback.socket;
-import org.apache.excalibur.altrmi.server.AltrmiServerException;
+import org.apache.excalibur.altrmi.server.ServerException;
import org.apache.excalibur.altrmi.server.impl.ServerStreamReadWriter;
import org.apache.excalibur.altrmi.server.impl.adapters.InvocationHandlerAdapter;
import
org.apache.excalibur.altrmi.server.impl.socket.AbstractCompleteSocketStreamServer;
@@ -31,10 +31,10 @@
*
* @param port
*
- * @throws AltrmiServerException
+ * @throws ServerException
*
*/
- public CallbackEnabledSocketCustomStreamServer( int port ) throws
AltrmiServerException
+ public CallbackEnabledSocketCustomStreamServer( int port ) throws
ServerException
{
super( port );
}
@@ -50,12 +50,12 @@
* @param invocationHandlerAdapter
* @param port
*
- * @throws AltrmiServerException
+ * @throws ServerException
*
*/
public CallbackEnabledSocketCustomStreamServer(
InvocationHandlerAdapter invocationHandlerAdapter, int port )
- throws AltrmiServerException
+ throws ServerException
{
super( invocationHandlerAdapter, port );
}
1.6 +5 -5
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackServerClientReadWriter.java
Index: CallbackServerClientReadWriter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackServerClientReadWriter.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- CallbackServerClientReadWriter.java 4 Jan 2003 22:17:19 -0000 1.5
+++ CallbackServerClientReadWriter.java 5 Jan 2003 23:24:45 -0000 1.6
@@ -9,8 +9,8 @@
import java.io.IOException;
import org.apache.excalibur.altrmi.client.impl.ClientStreamReadWriter;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
/**
* Class CallbackServerClientReadWriter
@@ -39,11 +39,11 @@
callbackEnabledCustomSocketStreamReadWriter;
}
- public AltrmiReply postRequest( AltrmiRequest altrmiRequest )
+ public Reply postRequest( Request altrmiRequest )
throws IOException, ClassNotFoundException
{
- AltrmiReply altrmiReply =
+ Reply altrmiReply =
m_callbackEnabledCustomSocketStreamReadWriter.postRequest(
altrmiRequest );
return altrmiReply;
1.9 +8 -8
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/classretrievers/AbstractDynamicGeneratorClassRetriever.java
Index: AbstractDynamicGeneratorClassRetriever.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/classretrievers/AbstractDynamicGeneratorClassRetriever.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- AbstractDynamicGeneratorClassRetriever.java 4 Jan 2003 22:17:20 -0000
1.8
+++ AbstractDynamicGeneratorClassRetriever.java 5 Jan 2003 23:24:45 -0000
1.9
@@ -11,8 +11,8 @@
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
-import org.apache.excalibur.altrmi.common.ProxyGenerator;
-import org.apache.excalibur.altrmi.server.AltrmiProxyGenerator;
+
+import org.apache.excalibur.altrmi.server.ProxyGenerator;
import org.apache.excalibur.altrmi.server.ClassRetriever;
import org.apache.excalibur.altrmi.server.PublicationDescription;
import org.apache.excalibur.altrmi.server.ClassRetrievalException;
@@ -29,7 +29,7 @@
* @version $Revision$
*/
public class AbstractDynamicGeneratorClassRetriever
- implements AltrmiProxyGenerator, ClassRetriever
+ implements ProxyGenerator, ClassRetriever
{
private String m_altrmiClasspath;
@@ -262,11 +262,11 @@
interfacesToExpose = publicationDescription.getInterfacesToExpose();
addInfs = publicationDescription.getAdditionalFacades();
- ProxyGenerator proxyGenerator;
+ org.apache.excalibur.altrmi.common.ProxyGenerator proxyGenerator;
try
{
- proxyGenerator = (ProxyGenerator) m_generatorClass.newInstance();
+ proxyGenerator = (org.apache.excalibur.altrmi.common.ProxyGenerator)
m_generatorClass.newInstance();
}
catch (InstantiationException e)
{
@@ -365,11 +365,11 @@
public void generateDeferred( ClassLoader classLoader )
{
- ProxyGenerator proxyGenerator;
+ org.apache.excalibur.altrmi.common.ProxyGenerator proxyGenerator;
try
{
- proxyGenerator = (ProxyGenerator) m_generatorClass.newInstance();
+ proxyGenerator = (org.apache.excalibur.altrmi.common.ProxyGenerator)
m_generatorClass.newInstance();
}
catch (InstantiationException e)
{
1.5 +8 -8
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/direct/DirectMarshalledServer.java
Index: DirectMarshalledServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/direct/DirectMarshalledServer.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- DirectMarshalledServer.java 4 Jan 2003 22:17:20 -0000 1.4
+++ DirectMarshalledServer.java 5 Jan 2003 23:24:45 -0000 1.5
@@ -7,10 +7,10 @@
*/
package org.apache.excalibur.altrmi.server.impl.direct;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationException;
-import org.apache.excalibur.altrmi.common.AltrmiMarshalledInvocationHandler;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.InvocationException;
+import org.apache.excalibur.altrmi.common.MarshalledInvocationHandler;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
import org.apache.excalibur.altrmi.server.impl.adapters.InvocationHandlerAdapter;
import
org.apache.excalibur.altrmi.server.impl.adapters.MarshalledInvocationHandlerAdapter;
@@ -23,7 +23,7 @@
* @version $Revision$
*/
public class DirectMarshalledServer extends AbstractServer
- implements AltrmiMarshalledInvocationHandler
+ implements MarshalledInvocationHandler
{
MarshalledInvocationHandlerAdapter m_marshalledInovcationHandlerAdapter;
@@ -117,7 +117,7 @@
* @return
*
*/
- public AltrmiReply handleInvocation( AltrmiRequest request )
+ public Reply handleInvocation( Request request )
{
if( getState() == STARTED )
@@ -126,7 +126,7 @@
}
else
{
- throw new AltrmiInvocationException( "Service is not started" );
+ throw new InvocationException( "Service is not started" );
}
}
}
1.4 +6 -6
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/direct/DirectServer.java
Index: DirectServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/direct/DirectServer.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DirectServer.java 21 Sep 2002 15:52:57 -0000 1.3
+++ DirectServer.java 5 Jan 2003 23:24:45 -0000 1.4
@@ -7,9 +7,9 @@
*/
package org.apache.excalibur.altrmi.server.impl.direct;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.InvocationException;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
import org.apache.excalibur.altrmi.server.impl.adapters.InvocationHandlerAdapter;
@@ -76,7 +76,7 @@
* @return
*
*/
- public AltrmiReply handleInvocation( AltrmiRequest request )
+ public Reply handleInvocation( Request request )
{
if( getState() == STARTED )
@@ -85,7 +85,7 @@
}
else
{
- throw new AltrmiInvocationException( "Service is not started" );
+ throw new InvocationException( "Service is not started" );
}
}
}
1.2 +6 -6
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/http/CustomHttpServer.java
Index: CustomHttpServlet.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/http/CustomHttpServlet.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- CustomHttpServlet.java 4 Jan 2003 22:17:20 -0000 1.4
+++ CustomHttpServlet.java 5 Jan 2003 23:24:46 -0000 1.5
@@ -7,8 +7,8 @@
*/
package org.apache.excalibur.altrmi.server.impl.http;
-import org.apache.excalibur.altrmi.server.AltrmiServerException;
-import org.apache.excalibur.altrmi.server.AltrmiPublisher;
+import org.apache.excalibur.altrmi.server.ServerException;
+import org.apache.excalibur.altrmi.server.Publisher;
import org.apache.excalibur.altrmi.server.impl.ServerCustomStreamReadWriter;
import javax.servlet.ServletException;
@@ -41,7 +41,7 @@
{
m_customHttpServer = new CustomHttpServer();
}
- catch (AltrmiServerException e)
+ catch (ServerException e)
{
throw new RuntimeException("TODO" + e.getMessage());
}
@@ -76,7 +76,7 @@
}
- public AltrmiPublisher getPublisher()
+ public Publisher getPublisher()
{
return m_customHttpServer;
1.6 +7 -7
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/piped/AbstractPipedServer.java
Index: AbstractPipedServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/piped/AbstractPipedServer.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- AbstractPipedServer.java 13 Oct 2002 11:54:27 -0000 1.5
+++ AbstractPipedServer.java 5 Jan 2003 23:24:46 -0000 1.6
@@ -10,7 +10,7 @@
import java.io.IOException;
import java.io.PipedInputStream;
import java.io.PipedOutputStream;
-import org.apache.excalibur.altrmi.common.AltrmiConnectionException;
+import org.apache.excalibur.altrmi.common.ConnectionException;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
import org.apache.excalibur.altrmi.server.impl.ServerStreamReadWriter;
import org.apache.excalibur.altrmi.server.impl.adapters.InvocationHandlerAdapter;
@@ -49,20 +49,20 @@
*
*
*
- * @throws AltrmiConnectionException
+ * @throws ConnectionException
*
*/
public void makeNewConnection( PipedInputStream in, PipedOutputStream out )
- throws AltrmiConnectionException
+ throws ConnectionException
{
if( getState() == UNSTARTED | getState() == STARTING)
{
- throw new AltrmiConnectionException( "Server not started yet" );
+ throw new ConnectionException( "Server not started yet" );
}
else if( getState() == SHUTTINGDOWN )
{
- throw new AltrmiConnectionException( "Server is Shutting down" );
+ throw new ConnectionException( "Server is Shutting down" );
}
try
@@ -89,7 +89,7 @@
}
catch( IOException pe )
{
- throw new AltrmiConnectionException( "Some problem setting up server : "
+ throw new ConnectionException( "Some problem setting up server : "
+ pe.getMessage() );
}
}
1.4 +4 -4
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/rmi/RmiInovcationAdapter.java
Index: RmiInovcationAdapter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/rmi/RmiInovcationAdapter.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- RmiInovcationAdapter.java 21 Sep 2002 15:52:57 -0000 1.3
+++ RmiInovcationAdapter.java 5 Jan 2003 23:24:46 -0000 1.4
@@ -8,8 +8,8 @@
package org.apache.excalibur.altrmi.server.impl.rmi;
import java.rmi.RemoteException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.RmiAltrmiInvocationHandler;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
@@ -50,7 +50,7 @@
* @throws RemoteException if a problem during processing
*
*/
- public AltrmiReply handleInvocation( AltrmiRequest request ) throws
RemoteException
+ public Reply handleInvocation( Request request ) throws RemoteException
{
return m_abstractServer.handleInvocation( request );
}
1.5 +5 -5
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/rmi/RmiServer.java
Index: AltrmiServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/AltrmiServer.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- AltrmiServer.java 21 Sep 2002 15:52:56 -0000 1.4
+++ AltrmiServer.java 5 Jan 2003 23:24:44 -0000 1.5
@@ -7,7 +7,7 @@
*/
package org.apache.excalibur.altrmi.server;
-import org.apache.excalibur.altrmi.common.AltrmiInvocationHandler;
+import org.apache.excalibur.altrmi.common.InvocationHandler;
/**
* Interface AltrmiServer
@@ -16,7 +16,7 @@
* @author Paul Hammant <a
href="mailto:[EMAIL PROTECTED]">[EMAIL PROTECTED]</a>
* @version * $Revision$
*/
-public interface AltrmiServer extends AltrmiPublisher, AltrmiInvocationHandler
+public interface AltrmiServer extends Publisher, InvocationHandler
{
/**
@@ -62,7 +62,7 @@
* @param altrmiAuthenticator we want to use.
*
*/
- void setAuthenticator( AltrmiAuthenticator altrmiAuthenticator );
+ void setAuthenticator( Authenticator altrmiAuthenticator );
/**
* Suspend publishing
@@ -79,10 +79,10 @@
/**
* Start publishing
*
* @throws AltrmiServerException if the server cannot start.
*
*/
- void start() throws AltrmiServerException;
+ void start() throws ServerException;
/**
* Stop publishing
1.5 +3 -3
@@ -79,10 +79,10 @@
* Start publishing
*
- * @throws AltrmiServerException if the server cannot start.
+ * @throws ServerException if the server cannot start.
*
*/
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/MethodInvocationHandler.java
Index: ServerCustomStreamReadWriter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerCustomStreamReadWriter.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- ServerCustomStreamReadWriter.java 28 Oct 2002 21:58:56 -0000 1.7
+++ ServerCustomStreamReadWriter.java 5 Jan 2003 23:24:44 -0000 1.8
@@ -11,10 +11,10 @@
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
import org.apache.excalibur.altrmi.common.SerializationHelper;
-import org.apache.excalibur.altrmi.common.AltrmiConnectionException;
+import org.apache.excalibur.altrmi.common.ConnectionException;
import org.apache.excalibur.altrmi.common.BadConnectionException;
/**
@@ -45,11 +45,11 @@
* @param altrmiReply The reply to send
* @return The new request
* @throws IOException In an IO Exception
* @throws AltrmiConnectionException In an IO Exception
* @throws ClassNotFoundException If a class not found during deserialization.
*/
- protected synchronized AltrmiRequest writeReplyAndGetRequest( AltrmiReply
altrmiReply )
- throws IOException, ClassNotFoundException, AltrmiConnectionException
+ protected synchronized Request writeReplyAndGetRequest( Reply altrmiReply )
+ throws IOException, ClassNotFoundException, ConnectionException
{
if( altrmiReply != null )
@@ -60,7 +60,7 @@
return readRequest();
}
- private void writeReply( AltrmiReply altrmiReply ) throws IOException
+ private void writeReply( Reply altrmiReply ) throws IOException
{
byte[] aBytes = SerializationHelper.getBytesFromInstance( altrmiReply );
@@ -89,7 +89,7 @@
super.close();
}
- private AltrmiRequest readRequest() throws IOException, ClassNotFoundException,
AltrmiConnectionException
+ private Request readRequest() throws IOException, ClassNotFoundException,
ConnectionException
{
int byteArraySize = m_dataInputStream.readInt();
if (byteArraySize < 0)
@@ -119,6 +119,6 @@
" reads to read all, " + byteArraySize + ", required bytes." );
}
*/
- return (AltrmiRequest)SerializationHelper.getInstanceFromBytes( byteArray );
+ return (Request)SerializationHelper.getInstanceFromBytes( byteArray );
}
}
1.7 +7 -7
@@ -45,11 +45,11 @@
* @return The new request
* @throws IOException In an IO Exception
- * @throws AltrmiConnectionException In an IO Exception
+ * @throws ConnectionException In an IO Exception
* @throws ClassNotFoundException If a class not found during deserialization.
*/
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerObjectStreamReadWriter.java
Index: ServerStreamReadWriter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/ServerStreamReadWriter.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ServerStreamReadWriter.java 28 Oct 2002 21:58:56 -0000 1.6
+++ ServerStreamReadWriter.java 5 Jan 2003 23:24:44 -0000 1.7
@@ -10,9 +10,9 @@
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
-import org.apache.excalibur.altrmi.common.AltrmiRequest;
-import org.apache.excalibur.altrmi.common.AltrmiConnectionException;
+import org.apache.excalibur.altrmi.common.Reply;
+import org.apache.excalibur.altrmi.common.Request;
+import org.apache.excalibur.altrmi.common.ConnectionException;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
/**
@@ -60,11 +60,11 @@
* @param altrmiReply The reply to pass back to the client
* @return The Request that is new and incoming
* @throws IOException if a problem during write & read.
* @throws AltrmiConnectionException if a problem during write & read.
* @throws ClassNotFoundException If a Class is not found during serialization.
*/
- protected abstract AltrmiRequest writeReplyAndGetRequest( AltrmiReply
altrmiReply )
- throws IOException, AltrmiConnectionException, ClassNotFoundException;
+ protected abstract Request writeReplyAndGetRequest( Reply altrmiReply )
+ throws IOException, ConnectionException, ClassNotFoundException;
/**
* Close the stream.
1.11 +10 -10
@@ -60,11 +60,11 @@
* @return The Request that is new and incoming
* @throws IOException if a problem during write & read.
- * @throws AltrmiConnectionException if a problem during write & read.
+ * @throws ConnectionException if a problem during write & read.
* @throws ClassNotFoundException If a Class is not found during serialization.
*/
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/StreamServerConnection.java
Index: CallbackServerClassAltrmiFactory.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/CallbackServerClassAltrmiFactory.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- CallbackServerClassAltrmiFactory.java 5 Jan 2003 23:11:28 -0000 1.7
+++ CallbackServerClassAltrmiFactory.java 5 Jan 2003 23:24:45 -0000 1.8
@@ -11,14 +11,14 @@
import org.apache.excalibur.altrmi.client.impl.AbstractHostContext;
import org.apache.excalibur.altrmi.client.impl.DefaultProxyHelper;
import org.apache.excalibur.altrmi.client.impl.ServerClassAltrmiFactory;
-import org.apache.excalibur.altrmi.common.AltrmiAuthentication;
-import org.apache.excalibur.altrmi.common.AltrmiConnectionException;
-import org.apache.excalibur.altrmi.common.AltrmiReply;
+import org.apache.excalibur.altrmi.common.Authentication;
+import org.apache.excalibur.altrmi.common.ConnectionException;
+import org.apache.excalibur.altrmi.common.Reply;
import org.apache.excalibur.altrmi.common.ExceptionReply;
import org.apache.excalibur.altrmi.common.LookupReply;
import org.apache.excalibur.altrmi.common.LookupRequest;
import org.apache.excalibur.altrmi.common.NotPublishedReply;
-import org.apache.excalibur.altrmi.common.AltrmiReplyConstants;
+import org.apache.excalibur.altrmi.common.ReplyConstants;
/**
* Class CallbackServerClassAltrmiFactory :
@@ -70,35 +70,35 @@
* @param publishedServiceName The published service name
* @param altrmiAuthentication An Authentication
* @return The object
* @throws AltrmiConnectionException if a proble during connection
*/
- public Object lookup( String publishedServiceName, AltrmiAuthentication
altrmiAuthentication )
- throws AltrmiConnectionException
+ public Object lookup( String publishedServiceName, Authentication
altrmiAuthentication )
+ throws ConnectionException
{
String modifiedPublishedName =
publishedServiceName.substring( 0, publishedServiceName.lastIndexOf(
"_" ) );
- AltrmiReply ar =
+ Reply ar =
m_hostContext.getClientInvocationHandler()
.handleInvocation( new LookupRequest( modifiedPublishedName,
altrmiAuthentication,
m_session ) );
- if( ar.getReplyCode() >= AltrmiReplyConstants.PROBLEMREPLY )
+ if( ar.getReplyCode() >= ReplyConstants.PROBLEMREPLY )
{
if( ar instanceof NotPublishedReply )
{
- throw new AltrmiConnectionException( "Service " +
publishedServiceName
+ throw new ConnectionException( "Service " + publishedServiceName
+ " not published" );
}
else if( ar instanceof ExceptionReply )
{
ExceptionReply er = (ExceptionReply)ar;
- throw (AltrmiConnectionException)er.getReplyException();
+ throw (ConnectionException)er.getReplyException();
}
else
{
- throw new AltrmiConnectionException( "Problem doing lookup on
service" );
+ throw new ConnectionException( "Problem doing lookup on service" );
}
}
1.8 +26 -26
@@ -70,35 +70,35 @@
* @param altrmiAuthentication An Authentication
* @return The object
- * @throws AltrmiConnectionException if a proble during connection
+ * @throws ConnectionException if a proble during connection
*/
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/callback/socket/CallbackEnabledSocketCustomStreamReadWriter.java
Index: CustomHttpServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/http/CustomHttpServer.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- CustomHttpServer.java 16 Dec 2002 01:00:01 -0000 1.1
+++ CustomHttpServer.java 5 Jan 2003 23:24:46 -0000 1.2
@@ -8,7 +8,7 @@
package org.apache.excalibur.altrmi.server.impl.http;
import org.apache.avalon.framework.logger.ConsoleLogger;
-import org.apache.excalibur.altrmi.server.AltrmiServerException;
+import org.apache.excalibur.altrmi.server.ServerException;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
import org.apache.excalibur.altrmi.server.impl.ServerCustomStreamReadWriter;
import org.apache.excalibur.altrmi.server.impl.ServerStreamReadWriter;
@@ -33,10 +33,10 @@
*
*
*
* @throws AltrmiServerException If a problem instantiating.
*
*/
- public CustomHttpServer() throws AltrmiServerException
+ public CustomHttpServer() throws ServerException
{
super();
// new RegistryHelper().put("/.altrmi/optimizations/port=" + port,
@@ -48,12 +48,12 @@
*
* @param invocationHandlerAdapter The invocation handler to use.
*
* @throws AltrmiServerException If a problem instantiating.
*
*/
public CustomHttpServer(
InvocationHandlerAdapter invocationHandlerAdapter)
- throws AltrmiServerException
+ throws ServerException
{
super(invocationHandlerAdapter);
// new RegistryHelper().put("/.altrmi/optimizations/port=" + port,
@@ -33,10 +33,10 @@
*
*
- * @throws AltrmiServerException If a problem instantiating.
+ * @throws ServerException If a problem instantiating.
*
*/
@@ -48,12 +48,12 @@
* @param invocationHandlerAdapter The invocation handler to use.
*
- * @throws AltrmiServerException If a problem instantiating.
+ * @throws ServerException If a problem instantiating.
*
*/
1.5 +5 -5
jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/http/CustomHttpServlet.java
Index: RmiServer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/altrmi/src/java/org/apache/excalibur/altrmi/server/impl/rmi/RmiServer.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- RmiServer.java 21 Sep 2002 15:52:57 -0000 1.4
+++ RmiServer.java 5 Jan 2003 23:24:46 -0000 1.5
@@ -13,7 +13,7 @@
import java.rmi.registry.Registry;
import java.rmi.server.UnicastRemoteObject;
import org.apache.excalibur.altrmi.common.RmiAltrmiInvocationHandler;
-import org.apache.excalibur.altrmi.server.AltrmiServerException;
+import org.apache.excalibur.altrmi.server.ServerException;
import org.apache.excalibur.altrmi.server.impl.AbstractServer;
import org.apache.excalibur.altrmi.server.impl.adapters.InvocationHandlerAdapter;
@@ -77,9 +77,9 @@
/**
* Start the server.
*
* @throws AltrmiServerException if an exception during starting.
*/
- public void start() throws AltrmiServerException
+ public void start() throws ServerException
{
setState(STARTING);
try
@@ -97,7 +97,7 @@
catch( RemoteException re )
{
getLogger().error("Error starting RMI server",re);
- throw new AltrmiServerException( "Some problem setting up server : "
+ throw new ServerException( "Some problem setting up server : "
+ re.getMessage() );
}
}
@@ -77,9 +77,9 @@
* Start the server.
*
- * @throws AltrmiServerException if an exception during starting.
+ * @throws ServerException if an exception during starting.
*/
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>